@@ -9,22 +9,13 @@ except ImportError:
 
 import sympy
 
-from mathpad.val import *
-from mathpad.units import *
+from mathpad.core import *
+from mathpad.maths import *
 
-from mathpad.solve import solve, Solution
-from mathpad.equation import Equation
-from mathpad._quality_of_life import t, pi, i, e, dimensionless, mathpad_constructor
-from mathpad.algebra import subs, simplify, factor, expand
-
-from mathpad.functions import piecewise, sqrt
-from mathpad.calculus import diff, integral
-from mathpad.trigonometry import cos, sin, tan
-from mathpad.vector_space import VectorSpace, R2, R3
-from mathpad.vector import Vector
-from mathpad.matrix import Matrix
+from mathpad.library.mathpad_constructor import mathpad_constructor
 from mathpad.simulate_dynamic_system import simulate_dynamic_system
-from mathpad.codegen import as_numpy_func
+
+import mathpad.codegen
 
 try:
     from IPython.display import display
@@ -35,4 +26,4 @@ except ImportError:
 sympy.init_printing()  # type: ignore
 sympy.printing.printer.Printer.set_global_settings(min=-3, max=4)  # type: ignore
 
-__version__ = "1.1.0"
+__version__ = "2.1.0"
